@@ -173,11 +173,11 @@ class Client:
         status: str = None,
         tags: list = [],
         offset: int = None,
-        limit: int = 100,
+        limit: int = 10,
     ) -> dict:
         """
         Returns a list of tasks.
-        Returns up to 1000 at a time, to get more, set offset as the starting position to fetch.
+        Returns up to 10 at a time, to get more, set offset as the starting position to fetch.
 
         project is slug of your project. (Required)
         status can be 'registered', 'in_progress', 'completed', 'skipped', 'in_review', 'send_backed', 'approved', 'customer_in_review', 'customer_send_backed', 'customer_approved'. (Optional)
@@ -185,6 +185,9 @@ class Client:
         offset is the starting position number to fetch. (Optional)
         limit is the max number to fetch. (Optional)
         """
+        if limit > 10:
+            raise FastLabelInvalidException(
+                "Limit must be less than or equal to 10.", 422)
         endpoint = "tasks/multi/image"
         params = {"project": project}
         if status:
